### mrpypulse

Mr. Py Pulse for generation and manipulation of Magnetic Resonance pulses in Python.

### modules

  - pulse, for creation and manipulation of pulses
  - magnetization, for simulation of pulses effect on magnetization
  - sequence, for creation and manipulation of sequence of pulses

### installation

```
pip install mrpypulse
```

### tests

Require pytest, inside the top-level `mrpypulse` directory, run:

```
pytest tests\
```
